@@ -1,4 +1,9 @@
-from cameo_claw import it_distinct, it_download, it_group, it_filter
+import json
+import sys
+
+import requests
+
+from cameo_claw import it_distinct, it_streaming, it_group, it_filter, server
 import time
 from cameo_claw.log import log
 
@@ -192,7 +197,7 @@ def get_lst_url_by_date(lst_device_id):
 def test_it_download():
     target_directory = './data/topic_download/'
     int_total = len(get_lst_url_taipei_100())
-    for int_progress, done_url in it_download(get_lst_url_taipei_100(), target_directory):
+    for int_progress, done_url in it_streaming(get_lst_url_taipei_100(), target_directory):
         # print_progress(done_url, int_progress, int_total)
         pass
 
@@ -238,7 +243,37 @@ def test_it_filter():
         # print_progress(done_url, int_progress, int_total)
 
 
+def test_server():
+    server()
+
+
+def test_client():
+    print('test.py test_client!')
+    d = {'lst_url': get_lst_url_taipei_100(),
+         'target_directory': './data/topic_filter/',
+         'lst_distinct_column': ['deviceId', 'localTime', 'sensorId'],
+         'lst_column_match': [['sensorId', 'pm2_5'], ['sensorId', 'voc']],
+         'sort_column': 'localTime'}
+    print(d)
+    r = requests.post('http://localhost:20409/api/streaming_post/', json=d)
+    print(f'http://localhost:20409/api/streaming_get/?md5_hex={r.text[1:-1]}')
+    with open('all.csv.gz', 'wb') as f:
+        f.write(r.content)
+
+
 if __name__ == '__main__':
+    print('sh/go.sh server')
+    print('sh/go.sh client')
+    print('sh/go.sh filter')
+    if sys.argv[1] == 'server':
+        test_server()
+    if sys.argv[1] == 'client':
+        test_client()
+    if sys.argv[1] == 'filter':
+        t = time.time()
+        test_it_filter()
+        log(f'test_it_filter:{time.time() - t}')
+
     # t = time.time()
     # test_it_download()
     # log(f'test_it_download:{time.time() - t}')
@@ -251,8 +286,4 @@ if __name__ == '__main__':
     # test_it_group()
     # log(f'test_it_group:{time.time() - t}')
 
-    t = time.time()
-    test_it_filter()
-    log(f'test_it_filter:{time.time() - t}')
-
 # sh/go.sh
